import { __decorate } from "tslib";
import * as fastComponents from '@microsoft/fast-components';
import { FASTElement, customElement, attr, observable, html, css, repeat, DOM, } from '@microsoft/fast-element';
import { EventName } from '../../types';
import { paletteFromColor } from '../../utils/utils';
const styles = css `
  .colors {
    display: flex;
    flex-wrap: wrap;
    list-style-type: none;
    margin: 0;
    padding: 0;
  }

  .color {
    flex-grow: 1;
    height: 20px;
  }
`;
const template = html `
  <ul class="colors">
    ${repeat((x) => x.swatches, html `
        <li class="color" style="background-color: ${(swatch) => swatch.toColorString()}"></li>
      `)}
  </ul>
`;
let ColorPalette = class ColorPalette extends FASTElement {
    constructor() {
        super(...arguments);
        this.swatches = [];
    }
    typeChanged() {
        if (this.type) {
            const paletteToken = fastComponents[this.type + 'Palette'];
            paletteToken.subscribe({
                handleChange: (change) => {
                    const palette = change.token.getValueFor(this);
                    this.swatches = [...palette.swatches];
                },
            }, this);
        }
    }
    handleStyleChanges(event) {
        const detail = event.detail;
        if (detail) {
            DOM.queueUpdate(() => {
                const palette = paletteFromColor(detail[`${this.type}Color`]);
                this.swatches = [...palette.swatches];
            });
        }
    }
    connectedCallback() {
        super.connectedCallback();
        document.body.addEventListener(EventName.STYLES_CHANGED, (e) => {
            this.handleStyleChanges(e);
        });
    }
};
__decorate([
    observable
], ColorPalette.prototype, "swatches", void 0);
__decorate([
    attr
], ColorPalette.prototype, "type", void 0);
ColorPalette = __decorate([
    customElement({
        name: 'color-palette',
        styles,
        template,
    })
], ColorPalette);
export { ColorPalette };
